"""Console script for img_processor."""
import sys
import click


@click.command()
def main(args=None):
    """Console script for img_processor."""
    click.echo("Running img_processor.cli.main...")
    click.echo("See click documentation at https://click.palletsprojects.com/")
    return 0


if __name__ == "__main__":
    sys.exit(main())  # pragma: no cover
